@@ -13,7 +13,6 @@ subclass of PluginMainWidget.
 
 # Standard library imports
 from collections import OrderedDict
-import os
 import sys
 import textwrap
 from typing import Optional
@@ -36,7 +35,8 @@ from spyder.api.widgets.toolbars import MainWidgetToolbar
 from spyder.utils.qthelpers import create_waitspinner, set_menu_icons
 from spyder.utils.registries import (
     ACTION_REGISTRY, TOOLBAR_REGISTRY, MENU_REGISTRY)
-from spyder.utils.stylesheet import APP_STYLESHEET, PANES_TABBAR_STYLESHEET
+from spyder.utils.stylesheet import (
+    APP_STYLESHEET, PANES_TABBAR_STYLESHEET, PANES_TOOLBAR_STYLESHEET)
 from spyder.widgets.dock import SpyderDockWidget
 from spyder.widgets.tabs import Tabs
 
@@ -227,6 +227,7 @@ class PluginMainWidget(QWidget, SpyderWidgetMixin, SpyderToolbarMixin):
             parent=self,
             name=PluginMainWidgetWidgets.CornerWidget,
         )
+        self._corner_widget.ID = 'main_corner'
 
         self._main_toolbar = MainWidgetToolbar(
             parent=self,
@@ -303,16 +304,17 @@ class PluginMainWidget(QWidget, SpyderWidgetMixin, SpyderToolbarMixin):
             icon=self.create_icon('tooloptions'),
         )
 
-        self.add_corner_widget(
-            PluginMainWidgetWidgets.OptionsToolButton,
-            self._options_button,
-        )
         if self.ENABLE_SPINNER:
             self.add_corner_widget(
                 PluginMainWidgetWidgets.Spinner,
                 self._spinner,
             )
 
+        self.add_corner_widget(
+            PluginMainWidgetWidgets.OptionsToolButton,
+            self._options_button,
+        )
+
         # Widget setup
         # --------------------------------------------------------------------
         self._main_toolbar.setVisible(not self._is_tab)
@@ -374,6 +376,7 @@ class PluginMainWidget(QWidget, SpyderWidgetMixin, SpyderToolbarMixin):
                 toolbar=self._corner_toolbar,
                 section="corner",
             )
+            self._corner_widget.setStyleSheet(str(PANES_TOOLBAR_STYLESHEET))
 
         # Update title
         self.setWindowTitle(self.get_title())
@@ -552,11 +555,10 @@ class PluginMainWidget(QWidget, SpyderWidgetMixin, SpyderToolbarMixin):
                 'Menu name "{}" already in use!'.format(menu_id)
             )
 
-        menu = MainWidgetMenu(parent=self, title=title)
-        menu.ID = menu_id
+        menu = MainWidgetMenu(parent=self, title=title, menu_id=menu_id)
 
         MENU_REGISTRY.register_reference(
-            menu, menu.ID, self.PLUGIN_NAME, self.CONTEXT_NAME)
+            menu, menu_id, self.PLUGIN_NAME, self.CONTEXT_NAME)
 
         if icon is not None:
             menu.menuAction().setIconVisibleInMenu(True)
@@ -869,8 +871,7 @@ class PluginMainWidget(QWidget, SpyderWidgetMixin, SpyderToolbarMixin):
         Create widget actions, add to menu and other setup requirements.
         """
         raise NotImplementedError(
-            'A PluginMainWidget subclass must define a `setup` '
-            'method!')
+            f'{type(self)} must define a `setup` method!')
 
     def update_actions(self):
         """
